@@ -9,4 +9,6 @@ def main():
                         help="path of archive from arche")
     parser.add_argument("--ws",
                         help="where to build workspace")
+    parser.add_argument("-v", "--verbose", help="increase output verbosity",
+                        action="store_true")
     fe = FastEval(parser.parse_args())
